;; Generated package description from guess-language.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "guess-language" "0.0.1" "Robust automatic language detection" '((cl-lib "0.5") (emacs "24") (nadvice "0.1")) :commit "43eb329c06ac5a39ce79d4f5d4bc7690a4d60353" :authors '(("Titus von der Malsburg" . "malsburg@posteo.de")) :maintainer '("Titus von der Malsburg" . "malsburg@posteo.de") :keywords '("wp") :url "https://github.com/tmalsburg/guess-language.el")
